@@ -7,11 +7,16 @@
 ##' @aliases getPost
 ##' @seealso \code{\link[btf]{getPostEst}}
 ##' @export
-getPost <- function(btf, parameter=c('beta', 's2', 'lambda', 'omega', 'alpha'),
-                    burn=1e3) {
+getPost <- function(btf, parameter=c('f', 's2', 'lambda', 'omega'), burn=1e3) {
     parameter <- match.arg(parameter)
-    idx <- grep(parameter, varnames(btf))
-    window(btf[,idx], start=burn)
+    samples <- btf[[parameter]]
+    w <- which(samples == 0, arr.ind=TRUE)
+    if (length(w)>0) {
+        out <- samples[-unique(w[,1]),]
+    } else {
+        out <- samples
+    }
+    window(as.mcmc(out), start=burn)
 }
 
 ##' get posterior estimates from btf object
@@ -22,12 +27,16 @@ getPost <- function(btf, parameter=c('beta', 's2', 'lambda', 'omega', 'alpha'),
 ##' @param btf btf object
 ##' @param parameter name of the paramater of interest
 ##' @param burn number of samples to discard
-##' @param est estimate of the object
+##' @param est function to estimate from the posterior samples of \code{parameter}
 ##' @aliases getPostEst
 ##' @seealso \code{\link[btf]{getPost}}
 ##' @export
-getPostEst <- function(btf, parameter=c('beta', 's2', 'lambda', 'omega', 'alpha'),
-                       burn=1e3, est=mean) {
+getPostEst <- function(btf, parameter=c('f', 's2', 'lambda', 'omega'),
+                       burn=1e3, est=NULL) {
     samples <- getPost(btf, parameter=match.arg(parameter), burn=burn)
-    apply(as.matrix(samples),2,match.fun(est))
+    if (missing(est)) {
+        summary(samples)
+    } else {
+        apply(as.matrix(samples),2,match.fun(est))
+    }
 }
